#!/usr/bin/env python
# -*- coding: UTF-8 -*-
# (c) 2015 Ticketbis
import logging; log = logging.getLogger(__name__)

from . import BaseAuthenticationTestCase
import six
import ticketbis


class OAuthEndpointTestCase(BaseAuthenticationTestCase):
    def test_auth_url(self):
        url = self.api.oauth.auth_url()
        assert isinstance(url, six.string_types)

    def test_get_token(self):
        # Honestly, not much we can do to test here
        pass



#!/usr/bin/env python
# -*- coding: UTF-8 -*-
# (c) 2015 Ticketbis

import os
import unittest

import ticketbis

if 'CLIENT_ID' in os.environ and 'CLIENT_SECRET' in os.environ \
        and 'ACCESS_TOKEN' in os.environ and 'API_ENDPOINT' in os.environ:
    CLIENT_ID = os.environ['CLIENT_ID']
    CLIENT_SECRET = os.environ['CLIENT_SECRET']
    ACCESS_TOKEN = os.environ['ACCESS_TOKEN']
    API_ENDPOINT = os.environ['API_ENDPOINT']
else:
    try:
        from ticketbis.tests._creds import *
    except ImportError:
        print("Please create a creds.py file in this package, based upon creds.example.py")


TEST_DATA_DIR = os.path.join(os.path.dirname(__file__), 'testdata')


class BaseEndpointTestCase(unittest.TestCase):
    default_site_name = 'ticketbisES'
    default_category_id = u'2'
    default_site_id = u'1'
    default_venue_id = u'1'
    default_schema_id = u'1'

class BaseAuthenticationTestCase(BaseEndpointTestCase):
    def setUp(self):
        self.api = ticketbis.Ticketbis(
            client_id=CLIENT_ID,
            client_secret=CLIENT_SECRET,
            redirect_uri='http://ticketbis.com',
            site=self.default_site_name,
            api_endpoint=API_ENDPOINT
        )

class BaseAuthenticatedEndpointTestCase(BaseEndpointTestCase):
    def setUp(self):
        self.api = ticketbis.Ticketbis(
#            client_id=CLIENT_ID,
#            client_secret=CLIENT_SECRET,
            access_token=ACCESS_TOKEN,
            site=self.default_site_name,
            api_endpoint=API_ENDPOINT
        )

class BaseUserlessEndpointTestCase(BaseEndpointTestCase):
    def setUp(self):
        self.api = ticketbis.Ticketbis(
            client_id=CLIENT_ID,
            client_secret=CLIENT_SECRET,
            site=self.default_site_name,
            api_endpoint=API_ENDPOINT
        )

class MultilangEndpointTestCase(BaseEndpointTestCase):
    def setUp(self):
        self.apis = []
        for lang in ('es', 'fr', 'de', 'it', 'ja', 'th', 'ko', 'ru', 'pt', 'id'):
            self.apis.append(
                ticketbis.Ticketbis(
                    client_id=CLIENT_ID,
                    client_secret=CLIENT_SECRET,
                    lang=lang,
                    api_endpoint=API_ENDPOINT
                )
            )



#!/usr/bin/env python
# -*- coding: UTF-8 -*-
# (c) 2015 Ticketbis
import logging; log = logging.getLogger(__name__)

import os

from . import TEST_DATA_DIR, BaseAuthenticatedEndpointTestCase

class EventsEndpointTestCase(BaseAuthenticatedEndpointTestCase):
    """
    General
    """

    def test_events(self):
        response = self.api.events(params={'max': 2, 'offset': 0})
        assert 'id' in response[0]
        assert self.api.page_max == 2
        assert self.api.page_offset == 0

        response = self.api.events(response[0]['id'])
        assert 'name' in response

    def test_events_by_category(self):
        response = self.api.categories.events(self.default_category_id, 
                params={'max': 2, 'offset': 0})
        assert 'name' in response[0]

    def test_event_pagination(self):
        response = self.api.events(auto_pagination=True, params={'max': 1})
        r = next(response)
        r = next(response)
        assert 'name' in r
